# geosdem


[![image](https://img.shields.io/pypi/v/geosdem.svg)](https://pypi.python.org/pypi/geosdem)
[![image](https://img.shields.io/conda/vn/conda-forge/geosdem.svg)](https://anaconda.org/conda-forge/geosdem)


**A python package for demo**


-   Free software: MIT license
-   Documentation: https://giswr.github.io/geosdem
    

## Features

-   TODO
